@@ -14,7 +14,6 @@ Changes for Python3 port © 2011-14 Scott Kitterman <scott@kitterman.com>
 import socket, string, types, time, select
 import errno
 from . import Type,Class,Opcode
-import asyncore
 #
 # This random generator is used for transaction ids and port selection.  This
 # is important to prevent spurious results from lost packets, and malicious
@@ -50,8 +49,12 @@ defaults= { 'protocol':'udp', 'port':53, 'opcode':Opcode.QUERY,
 
 def ParseResolvConf(resolv_path="/etc/resolv.conf"):
     "parses the /etc/resolv.conf file and sets defaults for name servers"
-    with open(resolv_path, 'r') as stream:
-        return ParseResolvConfFromIterable(stream)
+    try:
+        with open(resolv_path, 'r') as stream:
+            return ParseResolvConfFromIterable(stream)
+    except FileNotFoundError:
+        return(defaults['server'].append('127.0.0.1'))
+
 
 def ParseResolvConfFromIterable(lines):
     "parses a resolv.conf formatted stream and sets defaults for name servers"
@@ -94,7 +97,6 @@ class DnsRequest:
     """ high level Request object """
     def __init__(self,*name,**args):
         self.donefunc=None
-        self.py3async=None
         self.defaults = {}
         self.argparse(name,args)
         self.defaults = self.args
@@ -274,10 +276,7 @@ class DnsRequest:
                 self.sendTCPRequest(server)
         except socket.error as reason:
             raise SocketError(reason)
-        if self.py3async:
-            return None
-        else:
-            return self.response
+        return self.response
 
     def req(self,*name,**args):
         " needs a refactoring "
@@ -326,10 +325,7 @@ class DnsRequest:
                 self.sendTCPRequest(server)
         except socket.error as reason:
             raise SocketError(reason)
-        if self.py3async:
-            return None
-        else:
-            return self.response
+        return self.response
 
     def sendUDPRequest(self, server):
         "refactor me"
@@ -347,21 +343,18 @@ class DnsRequest:
                     # TODO. Handle timeouts &c correctly (RFC)
                     self.time_start=time.time()
                     self.conn()
-                    if not self.py3async:
-                        self.s.send(self.request)
+                    self.s.send(self.request)
+                    r=self.processUDPReply()
+                    # Since we bind to the source port and connect to the
+                    # destination port, we don't need to check that here,
+                    # but do make sure it's actually a DNS request that the
+                    # packet is in reply to.
+                    while (r.header['id'] != self.tid or
+                            self.from_address[1] != self.port):
                         r=self.processUDPReply()
-                        # Since we bind to the source port and connect to the
-                        # destination port, we don't need to check that here,
-                        # but do make sure it's actually a DNS request that the
-                        # packet is in reply to.
-                        while r.header['id'] != self.tid        \
-                                or self.from_address[1] != self.port:
-                            r=self.processUDPReply()
-                        self.response = r
-                        # FIXME: check waiting async queries
+                    self.response = r
                 finally:
-                    if not self.py3async:
-                        self.s.close()
+                    self.s.close()
             except socket.error as e:
                 # Keep trying more nameservers, but preserve the first error
                 # that occurred so it can be reraised in case none of the
@@ -418,40 +411,6 @@ class DnsRequest:
         if not self.response and first_socket_error:
             raise first_socket_error
 
-#class DnsAsyncRequest(DnsRequest):
-class DnsAsyncRequest(DnsRequest,asyncore.dispatcher_with_send):
-    " an asynchronous request object. out of date, probably broken "
-    def __init__(self,*name,**args):
-        DnsRequest.__init__(self, *name, **args)
-        # XXX todo
-        if 'done' in args and args['done']:
-            self.donefunc=args['done']
-        else:
-            self.donefunc=self.showResult
-        #self.realinit(name,args) # XXX todo
-        self.py3async=1
-    def conn(self):
-        self.getSource()
-        self.connect((self.ns,self.port))
-        self.time_start=time.time()
-        if 'start' in self.args and self.args['start']:
-            asyncore.dispatcher.go(self)
-    def socketInit(self,a,b):
-        self.create_socket(a,b)
-        asyncore.dispatcher.__init__(self)
-        self.s=self
-    def handle_read(self):
-        if self.args['protocol'] == 'udp':
-            self.response=self.processUDPReply()
-            if self.donefunc:
-                self.donefunc(*(self,))
-    def handle_connect(self):
-        self.send(self.request)
-    def handle_write(self):
-        pass
-    def showResult(self,*s):
-        self.response.show()
-
 def ParseOSXSysConfig():
     "Retrieves the current Mac OS X resolver settings using the scutil(8) command."
     import os, re
